"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DailyRewards = void 0;
const request_1 = require("../utils/request");
const error_1 = require("../utils/error");
class DailyRewards {
    /**
       *
       * @description Get the daily rewards details
       * @param {string} cookie The cookie to set
       * @param {string} language The language to set
       * @param {number} day get the day's rewards
       *
       */
    async getDayReward(day, language, cookie) {
        var _a;
        const instance = (0, request_1.request)({
            type: request_1.optionType.dailyrewards,
        });
        (0, request_1.setLanguage)(language);
        const res = await instance.get("/home", {
            headers: {
                "Cookie": cookie,
            },
            params: {
                "lang": language,
                "act_id": "e202102251931481",
            },
        });
        if (((_a = res.data) === null || _a === void 0 ? void 0 : _a.retcode) === 0) {
            const { data } = res;
            return data.data.awards[day - 1];
        }
        throw new error_1.APIError(res.data.message, res.data.retcode);
    }
    /**
     *
     * @description Claim the daily rewards
     * @param {string} language The language to set
     * @param {string} cookie The cookie to set
     */
    async claim(language, cookie) {
        var _a, _b, _c, _d;
        const instance = (0, request_1.request)({
            type: request_1.optionType.dailyrewards,
            withUA: true,
        });
        const res = await instance.post("/sign", {
            "act_id": "e202102251931481",
        }, {
            headers: {
                "Cookie": cookie,
                "Content-Type": "application/json",
            },
            params: {
                "lang": language,
            },
        });
        if (((_a = res.data) === null || _a === void 0 ? void 0 : _a.retcode) === -100) {
            return {
                status: "Invalid cookie",
                code: -100,
            };
        }
        if (((_b = res.data) === null || _b === void 0 ? void 0 : _b.retcode) === -5003) {
            return {
                status: "Already claimed",
                code: -5003,
            };
        }
        if (((_c = res.data) === null || _c === void 0 ? void 0 : _c.data.code) === "ok" && ((_d = res.data) === null || _d === void 0 ? void 0 : _d.data.retcode) === 0) {
            return {
                status: "success",
                code: 0,
            };
        }
        throw new error_1.APIError(res.data.message, res.data.retcode);
    }
}
exports.DailyRewards = DailyRewards;
