"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SpiralAbyss = void 0;
const tslib_1 = require("tslib");
const request_1 = require("../utils/request");
const generate_ds_1 = tslib_1.__importDefault(require("../utils/generate_ds"));
const getServer_1 = require("../utils/getServer");
const clientCache_1 = require("../client/clientCache");
const error_1 = require("../utils/error");
class SpiralAbyss {
    constructor() {
        Object.defineProperty(this, "cache", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: new clientCache_1.ClientCache()
        });
    }
    /**
       * @param {string} language The response language
       * @param {string} cookie The cookie to use for the request
       * @param {string} uid Genshin Impact game uid
       */
    async get(uid, language, cookie, previous) {
        var _a;
        const instance = (0, request_1.request)();
        (0, request_1.setLanguage)(language);
        const res = await instance.get("/spiralAbyss", {
            headers: {
                "x-rpc-client_type": "4",
                "x-rpc-app_version": "1.5.0",
                "DS": (0, generate_ds_1.default)(),
                "Cookie": cookie,
            },
            params: {
                "server": (0, getServer_1.checkServerRegion)(uid),
                "role_id": uid,
                "schedule_type": `${previous ? "2" : "1"}`,
            },
        });
        if (((_a = res.data) === null || _a === void 0 ? void 0 : _a.retcode) === 0) {
            const { data } = res;
            this.cache.set(uid, data.data);
            return data.data;
        }
        if (res.data.retcode === 10101) {
            return {
                status: "Cannot get data for more than 30 accounts per cookie per day",
                code: 10101,
            };
        }
        throw new error_1.APIError(res.data.message, res.data.retcode);
    }
}
exports.SpiralAbyss = SpiralAbyss;
